/*
 ThermostatQA - test framework for Thermostat Monitoring Tool

 Copyright 2015 Red Hat, Inc.

 This file is part of ThermostatQA

 ThermostatQA is distributed under the GNU General Public License,
 version 2 or any later version (with a special exception described
 below, commonly known as the "Classpath Exception").

 A copy of GNU General Public License (GPL) is included in this
 distribution, in the file COPYING.

 Linking ThermostatQA code with other modules is making a combined work
 based on ThermostatQA.  Thus, the terms and conditions of the GPL
 cover the whole combination.

 As a special exception, the copyright holders of ThermostatQA give you
 permission to link this code with independent modules to produce an
 executable, regardless of the license terms of these independent
 modules, and to copy and distribute the resulting executable under
 terms of your choice, provided that you also meet, for each linked
 independent module, the terms and conditions of the license of that
 module.  An independent module is a module which is not derived from
 or based on ThermostatQA code.  If you modify ThermostatQA, you may
 extend this exception to your version of the software, but you are
 not obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version.
 */
package org.thermostat.qa2.tests;

import static org.thermostat.qa2.framework.Assert.assertTrue;
import org.thermostat.qa2.framework.annotations.SetupStorage;
import org.thermostat.qa2.framework.annotations.Test;
import org.thermostat.qa2.framework.services.ThermostatService;
import org.thermostat.qa2.framework.utils.ProcessUtilities;

/**
 * Test class ported from old framework
 * @author Zdeněk Žamberský
 */
public class ServicesSmokeTest {

    public int getNumberOfRunningMongos() throws Exception {
        return ProcessUtilities.shellRunGetOutput("ps x | grep \"[m]ongod\" | grep -v mongodb24 || true").size();
    }

    public int getNumberOfRunningAgents() throws Exception {
        return ProcessUtilities.shellRunGetOutput("jps | grep Thermostat || true").size();
    }

    @Test
    @SetupStorage(type="mongo")
    public void serviceTest() throws Exception {
        assertTrue(getNumberOfRunningMongos() == 0, "there should be no db running before the test");
        assertTrue(getNumberOfRunningAgents() == 0, "there should not be any agent running before the test");

        ThermostatService service = new ThermostatService();
        service.start();

        assertTrue(getNumberOfRunningMongos() > 0, "the db should be running after service started");
        assertTrue(getNumberOfRunningAgents() > 0, "there should be >0 running thermostat agents");

        service.stop();

        assertTrue(getNumberOfRunningMongos() == 0, "there should be no db running after the test");
        assertTrue(getNumberOfRunningAgents() == 0, "there should not be any agent running after the test");
    }

}
